cgexplore.optimisation.CGOMMOptimizer
=====================================

.. currentmodule:: cgexplore.optimisation

.. autoclass:: CGOMMOptimizer
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~CGOMMOptimizer.calculate_energy
      ~CGOMMOptimizer.calculate_energy_decomposition
      ~CGOMMOptimizer.optimize
      ~CGOMMOptimizer.read_final_energy_decomposition
   
   

   
   
   